@@ -406,7 +406,7 @@ class CheckForNewVersion(threading.Thread):
                 # set the flag to lock that connection
                 s.CheckingForNewVersion = True
                 # remove newline
-                result = s.FetchURL("http://nagstamon.sourceforge.net/latest_version", giveback="raw")
+                result = s.FetchURL("http://nagstamon.sourceforge.net/latest_version_" + self.output.version, giveback="raw")
                 version, error = result.result.split("\n")[0], result.error
                 
                 # debug
@@ -471,9 +471,9 @@ class PlaySound(threading.Thread):
         # debug
         if str(self.conf.debug_mode) == "True":
             # once again taking .Debug() from first server
-            self.servers.values()[0].Debug(debug="Playing sound: " + file)
+            self.servers.values()[0].Debug(debug="Playing sound: " + str(file))
         if not platform.system() == "Windows":
-            commands.getoutput("play -q %s" % file)
+            commands.getoutput("play -q %s" % str(file))
         else:
             winsound.PlaySound(file, winsound.SND_FILENAME)
             
@@ -711,7 +711,7 @@ def OpenNagstamonDownload(output=None):
 
 def HostIsFilteredOutByRE(host, conf=None):
     """
-        helper for applying RE filters in nagstamonGUI.RefreshDisplay()
+        helper for applying RE filters in Generic.GetStatus()
     """
     try:
         if str(conf.re_host_enabled) == "True":
@@ -735,7 +735,7 @@ def HostIsFilteredOutByRE(host, conf=None):
         
 def ServiceIsFilteredOutByRE(service, conf=None):
     """
-        helper for applying RE filters in nagstamonGUI.RefreshDisplay()
+        helper for applying RE filters in Generic.GetStatus()
     """
     try:
         if str(conf.re_service_enabled) == "True":
@@ -755,7 +755,29 @@ def ServiceIsFilteredOutByRE(service, conf=None):
         return False
     except:
         pass
+
     
+def StatusInformationIsFilteredOutByRE(status_information, conf=None):
+    """
+        helper for applying RE filters in Generic.GetStatus()
+    """
+    try:
+        if str(conf.re_status_information_enabled) == "True":
+            pattern = re.compile(conf.re_status_information_pattern)       
+            if len(pattern.findall(status_information)) > 0:
+                if str(conf.re_status_information_reverse) == "True":
+                    return False
+                else:
+                    return True
+            else:
+                if str(conf.re_status_information_reverse) == "True":
+                    return True 
+                else:
+                    return False    
+        return False
+    except:
+        pass 
+
 
 def HumanReadableDuration(seconds):
     """
