@@ -1,6 +1,6 @@
 # encoding: utf-8
 
-import urllib
+import urllib, urllib2
 import webbrowser
 import socket
 import time
@@ -47,33 +47,30 @@ class CentreonServer(GenericServer):
     def open_tree_view(self, host, service=""):
         # must be a host if service is empty...
         if service == "":
-            webbrowser.open(self.nagios_cgi_url + "/index.php?" + urllib.urlencode({"p":201, "autologin":1,\
-            "o":"hd", "useralias":self.MD5_username, "password":self.MD5_password, "host_name":host}))
+            webbrowser.open(self.nagios_cgi_url + "/main.php?" + urllib.urlencode({"p":201,"o":"hd", "host_name":host}))
         else:
-            webbrowser.open(self.nagios_cgi_url + "/index.php?" + urllib.urlencode({"p":202, "autologin":1,\
-            "o":"svcd", "useralias":self.MD5_username, "password":self.MD5_password, "host_name":host,\
-             "service_description":service}))       
+            webbrowser.open(self.nagios_cgi_url + "/main.php?" + urllib.urlencode({"p":202, "o":"svcd",  "host_name":host, "service_description":service}))      
 
             
     def open_nagios(self):
-        webbrowser.open(self.nagios_cgi_url + "/index.php?autologin=1&p=1&useralias=" + self.MD5_username + "&password=" + self.MD5_password)
+        webbrowser.open(self.nagios_cgi_url + "/main.php?p=1")
         # debug
         if str(self.conf.debug_mode) == "True":
-            self.Debug(server=self.get_name(), debug="Open monitor web page " + self.nagios_url + "/index.php?autologin=1&p=1&useralias=" + self.MD5_username + "&password=" + self.MD5_password)
+            self.Debug(server=self.get_name(), debug="Open monitor web page " + self.nagios_url + "/main.php?p=1")
 
         
     def open_services(self):
-        webbrowser.open(self.nagios_cgi_url + "/index.php?autologin=1&p=1&useralias=" + self.MD5_username + "&password=" + self.MD5_password + "&p=20202&o=svcpb")
+        webbrowser.open(self.nagios_cgi_url + "/main.php?p=20202&o=svcpb")
         # debug
         if str(self.conf.debug_mode) == "True":
-            self.Debug(server=self.get_name(), debug="Open services web page " + "/index.php?p=20202&o=svcpb")
+            self.Debug(server=self.get_name(), debug="Open services web page " + "/main.php?p=20202&o=svcpb")
 
             
     def open_hosts(self):
-        webbrowser.open(self.nagios_cgi_url + "/index.php?autologin=1&p=1&useralias=" + self.MD5_username + "&password=" + self.MD5_password + "&p=20103&o=hpb")
+        webbrowser.open(self.nagios_cgi_url + "/main.php?p=20103&o=hpb")
         # debug
         if str(self.conf.debug_mode) == "True":
-            self.Debug(server=self.get_name(), debug="Open hosts web page " + self.nagios_url + "/index.php?autologin=1&p=1&useralias=" + self.MD5_username + "&password=" + self.MD5_password + "&p=20103&o=hpb")
+            self.Debug(server=self.get_name(), debug="Open hosts web page " + self.nagios_url + "/main.php?p=20103&o=hpb")
             
             
     def get_start_end(self, host):
@@ -81,20 +78,28 @@ class CentreonServer(GenericServer):
         get start and end time for downtime from Centreon server
         """
         try:
-            cgi_data = urllib.urlencode({"p":"20305",\
+            cgi_data = urllib.urlencode({"p":"20106",\
                                          "o":"ah",\
                                          "host_name":host})
-            result = self.FetchURL(self.nagios_cgi_url + "/main.php?" + cgi_data, giveback="raw")
-            raw, error = result.result, result.error
+            #result = self.FetchURL(self.nagios_cgi_url + "/main.php?" + cgi_data, giveback="raw")
+            #raw, error = result.result, result.error
+            result = self.FetchURL(self.nagios_cgi_url + "/main.php?" + cgi_data, giveback="obj")
+            html, error = result.result, result.error
             if error == "":
                 # session id might have been invalid, so if necessary get a new one
-                if raw.find('name="start" type="text" value="') == -1:
-                    self.SID = self._get_sid().result
-                    result = self.FetchURL(self.nagios_cgi_url + "/main.php?" + cgi_data, giveback="raw")
-                    raw, error = result.result, result.error
-                start_time = raw.split('name="start" type="text" value="')[1].split('"')[0]
-                end_time = raw.split('name="end" type="text" value="')[1].split('"')[0]
-                del raw
+                ###if raw.find('name="start" type="text" value="') == -1:
+                ###    self.SID = self._get_sid().result
+                ###    result = self.FetchURL(self.nagios_cgi_url + "/main.php?" + cgi_data, giveback="raw")
+                ###    raw, error = result.result, result.error
+                ###start_time = raw.split('name="start" type="text" value="')[1].split('"')[0]
+                ###end_time = raw.split('name="end" type="text" value="')[1].split('"')[0]
+                
+                html = result.result
+                start_time = html.find(attrs={"name":"start"}).attrMap["value"]
+                end_time = html.find(attrs={"name":"end"}).attrMap["value"]                  
+                    
+                
+                ###del raw
                 # give values back as tuple      
                 return start_time, end_time
         except:
@@ -107,6 +112,10 @@ class CentreonServer(GenericServer):
         Centreonified way to get host ip - attribute "a" in down hosts xml is of no use for up
         hosts so we need to get ip anyway from web page
         """
+        # the fastest method is taking hostname as used in monitor
+        if str(self.conf.connect_by_host) == "True":
+            return Result(result=host)        
+        
         # do a web interface search limited to only one result - the hostname
         cgi_data = urllib.urlencode({"sid":self.SID,\
                                     "search":host,\
@@ -118,29 +127,25 @@ class CentreonServer(GenericServer):
                                     "o":"h",\
                                     "p":20102,\
                                     "time":0})
-        
+                
         result = self.FetchURL(self.nagios_cgi_url + "/include/monitoring/status/Hosts/xml/hostXML.php?"\
-                              + cgi_data, giveback="raw")
-        raw = result.result
-        # cut off <xml blabla>
-        xmlraw = ElementTree.fromstring(raw.split("\n")[1])
-        xmlobj = Actions.ObjectifyXML(xmlraw)   
-        del raw, xmlraw
-
+                              + cgi_data, giveback="xml")        
+        xmlobj = result.result
+        
         if len(xmlobj) != 0:
             # when connection by DNS is not configured do it by IP
             try:
-                if str(self.conf.connect_by_dns_yes) == "True":
+                if str(self.conf.connect_by_dns) == "True":
                    # try to get DNS name for ip, if not available use ip
                     try:
-                        address = socket.gethostbyaddr(xmlobj[0].a.text)[0]
+                        address = socket.gethostbyaddr(xmlobj.l.a.text)[0]
                         del xmlobj
                     except:
                         self.Error(sys.exc_info())
-                        address = str(xmlobj[0].a.text)                        
+                        address = str(xmlobj.l.a.text)                        
                         del xmlobj
                 else:
-                    address = str(xmlobj[0].a.text)
+                    address = str(xmlobj.l.a.text)
                     del xmlobj
             except:
                 result, error = self.Error(sys.exc_info())
@@ -162,8 +167,10 @@ class CentreonServer(GenericServer):
         gets a shiny new SID for XML HTTP requests to Centreon cutting it out via .partition() from raw HTML
         additionally get php session cookie
         """
+        login_data = urllib.urlencode({"useralias" : self.conf.servers[self.get_name()].username, "password" : self.conf.servers[self.get_name()].password, "submit" : "Login"})
+        
         try:
-            raw = self.FetchURL(self.nagios_cgi_url + "/index.php?" + urllib.urlencode({"p":1, "autologin":1, "useralias":self.MD5_username, "password":self.MD5_password}), giveback="raw")
+            raw = self.FetchURL(self.nagios_cgi_url + "/index.php",cgi_data=login_data, giveback="raw")
             del raw
             sid = str(self.Cookie._cookies.values()[0].values()[0]["PHPSESSID"].value)
             return Result(result=sid)
@@ -176,26 +183,14 @@ class CentreonServer(GenericServer):
         """
         get host_id via parsing raw html
         """
-        cgi_data = urllib.urlencode({"p":201, "autologin":1,\
-                                    "o":"hd", "host_name":host,\
-                                    "useralias":self.MD5_username,\
-                                    "password":self.MD5_password})
-        result = self.FetchURL(self.nagios_cgi_url + "/main.php?" + cgi_data, giveback="raw")
+        cgi_data = urllib.urlencode({"p":201,\
+                                    "o":"hd", "host_name":host})
+        result = self.FetchURL(self.nagios_cgi_url + "/main.php?" + cgi_data, cgi_data=urllib.urlencode({"sid":self.SID}), giveback="raw")
         raw, error = result.result, result.error
 
         if error == "":
             host_id = raw.partition("var host_id = '")[2].partition("'")[0]
             del raw
-            # if for some reason host_id could not be retrieved because
-            # we get a login page clear cookies and SID and try again
-            if host_id == "":
-                if str(self.conf.debug_mode) == "True":
-                    self.Debug(server=self.get_name(), debug = "Host ID could not be retrieved, trying again...")
-                self.SID = self._get_sid().result
-                result = self.FetchURL(self.nagios_cgi_url + "/main.php?" + cgi_data, giveback="raw")
-                raw, error = result.result, result.error
-                host_id = raw.partition("var host_id= '")[2].partition("'")[0]
-                del raw
         else:
             if str(self.conf.debug_mode) == "True":
                 self.Debug(server=self.get_name(), debug = "Host ID could not be retrieved.")
@@ -219,25 +214,19 @@ class CentreonServer(GenericServer):
         """
         parse a ton of html to get a host and a service id...
         """
-        cgi_data = urllib.urlencode({"p":"20305",\
+        cgi_data = urllib.urlencode({"p":"20218",\
                                      "host_name":host,\
                                      "service_description":service,\
                                      "o":"as"})
-        result = self.FetchURL(self.nagios_cgi_url + "/main.php?"+ cgi_data, giveback="raw")
+        # might look strange to have cgi_data 2 times, the first it is the "real" in URL and the second is the cgi_data parameter
+        # from urllib to get the session id POSTed
+        result = self.FetchURL(self.nagios_cgi_url + "/main.php?"+ cgi_data, cgi_data=urllib.urlencode({"sid":self.SID}), giveback="raw")
         raw, error = result.result, result.error
         
-        # ids to give back, should contain to items, a host and a service id
+        # ids to give back, should contain two items, a host and a service id
         ids = []
         
         if error == "":
-            if raw.find('selected="selected"') == -1:
-                # looks there was this old SID problem again - get a new one 
-                if str(self.conf.debug_mode) == "True":
-                    self.Debug(server=self.get_name(), host=host, service=service, debug = "IDs could not be retrieved, trying again...")                
-                self.SID = self._get_sid().result
-                result = self.FetchURL(self.nagios_cgi_url + "/main.php?"+ cgi_data, giveback="raw")
-                raw, error = result.result, result.error
-                
             # search ids
             for l in raw.splitlines():
                 if l.find('selected="selected"') <> -1:
@@ -279,7 +268,7 @@ class CentreonServer(GenericServer):
             if error != "": return Result(result=xmlobj, error=error)
 
             # in case there are no children session id is invalid
-            if xmlobj == "<response>bad session id</response>":    
+            if xmlobj == "<response>bad session id</response>" or xmlobj == "Bad Session ID":    
                 del xmlobj
                 if str(self.conf.debug_mode) == "True": 
                     self.Debug(server=self.get_name(), debug="Bad session ID, retrieving new one...")                
@@ -362,13 +351,12 @@ class CentreonServer(GenericServer):
             if error != "": return Result(result=xmlobj, error=error)
             
             # in case there are no children session id is invalid
-            if xmlobj == "<response>bad session id</response>": 
+            if xmlobj == "<response>bad session id</response>" or xmlobj == "Bad Session ID": 
                 # debug
                 if str(self.conf.debug_mode) == "True": 
                     self.Debug(server=self.get_name(), debug="Bad session ID, retrieving new one...")                                
                 # try again...
                 self.SID = self._get_sid().result
-                #result = self.FetchURL(nagcgiurl_services, giveback="raw")  
                 result = self.FetchURL(nagcgiurl_services, giveback="xml")                
                 xmlobj, error = result.result, result.error                
                 if error != "": return Result(result=xmlobj, error=error)
@@ -463,7 +451,6 @@ class CentreonServer(GenericServer):
                         "persistent":int(persistent), "sticky":int(sticky), "ackhostservice":"0", "o":"hd", "en":"1"})
                 # debug
                 if str(self.conf.debug_mode) == "True": 
-                    #print self.get_name(), host +": " + self.nagios_cgi_url + "/main.php?"+ cgi_data     
                     self.Debug(server=self.get_name(), host=host, debug=self.nagios_cgi_url + "/main.php?"+ cgi_data)                
 
                 # running remote cgi command, also possible with GET method     
@@ -538,8 +525,9 @@ class CentreonServer(GenericServer):
             if service == "":
                 # host
                 host_id = self._get_host_id(host)
-                cgi_data = urllib.urlencode({"p":"20305",\
+                cgi_data = urllib.urlencode({"p":"20106",\
                                              "host_id":host_id,\
+                                             "host_or_hg[host_or_hg]":1,\
                                              "submitA":"Save",\
                                              "persistent":int(fixed),\
                                              "persistant":int(fixed),\
@@ -554,7 +542,7 @@ class CentreonServer(GenericServer):
             else:
                 # service
                 host_id, service_id = self._get_host_and_service_id(host, service)
-                cgi_data = urllib.urlencode({"p":"20305",\
+                cgi_data = urllib.urlencode({"p":"20218",\
                                              "host_id":host_id,\
                                              "service_id":service_id,\
                                              "submitA":"Save",\
@@ -580,6 +568,7 @@ class CentreonServer(GenericServer):
         """
         # a SIDcount of 300 should make 15 min when being run every 3 secs as it is at 
         # the moment in Actions.RefreshLoopOneServer()
+        # maybe this is unnecessary now that we authenticate via login/password, no md5
         if self.SIDcount >= 300:
             if str(self.conf.debug_mode) == "True":
                 self.Debug(server=self.get_name(), debug="Old SID: " + self.SID + " " + str(self.Cookie))                
