@@ -36,7 +36,7 @@ class NinjaServer(GenericServer):
         self.STATUS_MAPPING = { "acknowledged.png" : "acknowledged",\
                                 "active-checks-disabled.png" : "passiveonly",\
                                 "notify-disabled.png" : "notifications_disabled",\
-                                "scheduled_downtime.png" : "scheduled_downtime",\
+                                "scheduled-downtime.png" : "scheduled_downtime",\
                                 "flapping.gif" : "flapping" }   
 
         # Entries for monitor default actions in context menu
@@ -190,7 +190,7 @@ class NinjaServer(GenericServer):
         # this dictionary is only temporarily
         nagitems = {"services":[], "hosts":[]}
 
-        nagiosurl_services = self.nagios_url + "/index.php/status/service/all?servicestatustypes=78&hoststatustypes=71"
+        nagiosurl_services = self.nagios_url + "/index.php/status/service/all?servicestatustypes=78&hoststatustypes=71&items_per_page=10000"
         nagiosurl_hosts = self.nagios_url + "/index.php/status/host/all/6"
 
         # Hosts
